@@ -71,6 +71,8 @@ class FactoryMaterialItem(scrapy.Item):
     manner_packing=scrapy.Field() #包装方式
     layout_design=scrapy.Field()  #电路图
     other_pdf_url=scrapy.Field()  #其他规格书{"名称":"pdf链接"}
+    raw_pdf_url = scrapy.Field()
+    raw_img_url = scrapy.Field()
 
 
 class FactoryMaterialItemMongo(scrapy.Item):
@@ -111,7 +113,8 @@ class FactoryMaterialItemMongo(scrapy.Item):
     manner_packing=scrapy.Field() #包装方式
     layout_design=scrapy.Field()  #电路图
     other_pdf_url=scrapy.Field()  #其他规格书{"名称":"pdf链接"}
-
+    raw_pdf_url = scrapy.Field()
+    raw_img_url = scrapy.Field()
     
 class FactoryCatergoryItem(scrapy.Item):
     table = 'ware_category' # 测试库bd-crawler 正式库bd-spider
